@@ -33,16 +33,6 @@ class AccessCategory(str, Enum):
     unknown_category = "unknown-category"
 
 
-class AccessRequest(OpenModuleModel):
-    """
-    The AccessRequest Model
-    """
-    name: str
-    gateway: Optional[Gateway] = None
-    medium_type: MediumType
-    id: str
-
-
 def check_recurrence(cls, recurrence, values, **kwargs):
     if recurrence:
         if not values.get("duration"):
@@ -139,6 +129,32 @@ class Access(OpenModuleModel):
             return between_start_and_end
 
 
+class BackendRegisterRequestMessage(ZMQMessage):
+    """
+    sent by the controller as a request to all backends
+    each backend who wants to register itself at the controller has to answer
+    with a register message
+    """
+    type: str = "register_request"
+
+
+class BackendRegisterMessage(ZMQMessage):
+    """
+    sent by a backend if it wants to register itself at the controller
+    """
+    type: str = "register"
+
+
+class AccessRequest(OpenModuleModel):
+    """
+    The AccessRequest Model
+    """
+    name: str
+    gateway: Optional[Gateway] = None
+    medium_type: MediumType
+    id: str
+
+
 class MediumAccesses(OpenModuleModel):
     accesses: List[Access]
     id: str
@@ -161,6 +177,8 @@ class CountMessage(ZMQMessage):
     zone: str
     category: AccessCategory
     real: bool
+    vehicle_id: Optional[str]
+    infos: Optional[dict]
     access_data: Optional[dict]
     error: Optional[str]
     previous_transaction_id: Optional[List[str]]  # double_entry, choose_random error
