@@ -72,7 +72,7 @@ class PresenceSimulator:
         return VehicleBuilder()
 
     def _common_kwargs(self, vehicle):
-        timestamp = datetime_to_timestamp(datetime.now())
+        timestamp = datetime_to_timestamp(datetime.utcnow())
         return {
             "vehicle_id": vehicle.vehicle_id,
             "unsure": False,
@@ -102,7 +102,7 @@ class PresenceSimulator:
             vehicle = self.leave()
         self.emit(PresenceForwardMessage(
             **self._common_kwargs(vehicle),
-            **{"leave-time": datetime_to_timestamp(datetime.now())}
+            **{"leave-time": datetime_to_timestamp(datetime.utcnow())}
         ))
 
     def backward(self, vehicle: Optional[VehicleBuilder] = None):
@@ -111,7 +111,7 @@ class PresenceSimulator:
             vehicle = self.leave()
         self.emit(PresenceBackwardMessage(
             **self._common_kwargs(vehicle),
-            **{"leave-time": datetime_to_timestamp(datetime.now())}
+            **{"leave-time": datetime_to_timestamp(datetime.utcnow())}
         ))
 
     def change(self, vehicle: VehicleBuilder):
